==> v1.3.0.2.zip: java_compdf_background/background-user/src/main/java/cn/kdan/compdf/service/BackgroundUserService.java <==
package cn.kdan.compdf.service;

import cn.kdan.compdf.base.R;
import cn.kdan.compdf.dto.ChangePasswordDTO;
import cn.kdan.compdf.dto.LoginDTO;
import cn.kdan.compdf.dto.LoginUser;
import cn.kdan.compdf.dto.LoginUserDTO;
import cn.kdan.compdf.entity.BackgroundUser;
import cn.kdan.compdf.vo.LoginVO;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.time.LocalDateTime;

/**
 * @author comPDF-Kit WPH 2022-10-09
 */
public interface BackgroundUserService extends IService<BackgroundUser> {

    /**
     * 列表查询
     *
     * @param query 查询参数
     * @return 列表数据
     */
    IPage<BackgroundUser> page(BackgroundUser query);

    R<LoginVO> login(LoginDTO loginDTO);

    void logout(String token);

    void changePassword(ChangePasswordDTO changePasswordDTO, String token);

    /**
     * 根据tenantID查userId
     */
    Long getUserId(Long tenantId);

    /**
     * 获得用户首次登录时间
     *
     * @param tenantId 用户id
     * @return 用户首次登录时间
     */
    LocalDateTime getUSerFirstLogin(Long tenantId);

    /**
     * 用户初始化资产信息
     *
     * @param userId   userId
     * @param tenantId tenantId
     */
    void userInit(Long userId, Long tenantId);

    /**
     * 通过邮箱（用户名）获取用户信息
     *
     * @param loginUser 邮箱和ComPDFKit-id
     * @return 用户信息
     */
    LoginUserDTO getUserInfo(LoginUser loginUser);

    /**
     * 通过邮箱（用户名）创建用户
     *
     * @param loginUser 邮箱和ComPDFKit-id
     * @return 用户信息
     */
    LoginUserDTO creatUser(LoginUser loginUser);

    Long getCompdfkitId(Long tenantId);
}

==> v1.3.0.4.zip: java_compdf_background/background-user/src/main/java/cn/kdan/compdf/service/BackgroundUserService.java <==
package cn.kdan.compdf.service;

import cn.kdan.compdf.base.R;
import cn.kdan.compdf.dto.ChangePasswordDTO;
import cn.kdan.compdf.dto.LoginDTO;
import cn.kdan.compdf.dto.LoginUser;
import cn.kdan.compdf.dto.LoginUserDTO;
import cn.kdan.compdf.entity.BackgroundUser;
import cn.kdan.compdf.vo.LoginVO;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.time.LocalDateTime;

/**
 * @author comPDF-Kit WPH 2022-10-09
 */
public interface BackgroundUserService extends IService<BackgroundUser> {

    /**
     * 列表查询
     *
     * @param query 查询参数
     * @return 列表数据
     */
    IPage<BackgroundUser> page(BackgroundUser query);

    R<LoginVO> login(LoginDTO loginDTO);

    void logout(String token);

    void changePassword(ChangePasswordDTO changePasswordDTO, String token);

    /**
     * 根据tenantID查userId
     */
    Long getUserId(Long tenantId);

    /**
     * 获得用户首次登录时间
     *
     * @param tenantId 用户id
     * @return 用户首次登录时间
     */
    LocalDateTime getUSerFirstLogin(Long tenantId);

    /**
     * 用户初始化资产信息
     *
     * @param userId   userId
     * @param tenantId tenantId
     */
    void userInit(Long userId, Long tenantId, Integer assets);

    /**
     * 通过邮箱（用户名）获取用户信息
     *
     * @param loginUser 邮箱和ComPDFKit-id
     * @return 用户信息
     */
    LoginUserDTO getUserInfo(LoginUser loginUser);

    /**
     * 通过邮箱（用户名）创建用户
     *
     * @param loginUser 邮箱和ComPDFKit-id
     * @return 用户信息
     */
    LoginUserDTO creatUser(LoginUser loginUser);

    Long getCompdfkitId(Long tenantId);
}
